ggmosaic2: Mosaic Plots in the 'ggplot2' Framework, Extended
Source:R/ggmosaic-package.R
ggmosaic2-package.RdMosaic plots in the 'ggplot2' framework. Mosaic plot functionality is provided in a single 'ggplot2' layer by calling the geom 'mosaic'. This extends the now-defunct 'ggmosaic' package by allowing fitted loglinear models which can be used to show patterns of association among variables in frequency tables.
Author
Maintainer: Michael Friendly friendly@yorku.ca (ORCID) [copyright holder]
Authors:
Michael Friendly friendly@yorku.ca (ORCID) [copyright holder]
Gavin Klorfine gklorfin@yorku.ca (ORCID)
Haley Jeppson hjeppson@iastate.edu (ORCID)
Heike Hofmann hofmann@iastate.edu (ORCID)
Di Cook dicook@monash.edu (ORCID)
Other contributors:
Hadley Wickham hadley@posit.co (ORCID) [contributor]